# -----------------------------------------------------------------------------
#                           Script to load the data
#          and transform into a list to be read in BUGS / JAGS / STAN
# -----------------------------------------------------------------------------


# Load the data and select the period of interest
# -----------------------------------------------
                               
temp <- read.table(file = "T_Oir_StHilaire_87_02.txt", header = TRUE, sep = "")
temp <- temp[,c(5,6)]

head(temp)
dim(temp)
summary(temp)


# Indices to select data for the time interval 1st June - 30 Sept - 1987
summer1.b <- 151
summer1.e <- 273

# Indices to select data for the time interval 1st June - 30 Sept - 1987
summer2.b <- 1978
summer2.e <- 2099


# Data for fitting the model
data <-  temp[summer1.b:summer1.e,]

# Data for prediction (summer 2002)
data.2002 <- temp[summer2.b:summer2.e,]


# -----------------------------------------------------------------------------
#                      Transform data into BUGS / JAS format
# -----------------------------------------------------------------------------

library(BRugs)

n <- dim(data)[1]
n.2002 <- dim(data.2002)[1]
Ta.2002 <- data.2002[,2]
Ta.2002 <- as.list(as.data.frame(Ta.2002))

Tw.2002 <- data.2002[,1]
Tw.2002 <- as.list(as.data.frame(Tw.2002))

bugsData(data = c("n"=n,as.list(data)), fileName = "data.txt", digits=6)
bugsData(data = c("n.2002" = n.2002,Ta.2002,Tw.2002), fileName = "data.2002.txt", digits=6)



